@@ -5,9 +5,10 @@ import requests
 
 from ...client import AuthenticatedClient
 from ...models.osidb_api_v1_flaws_list_impact import OsidbApiV1FlawsListImpact
-from ...models.osidb_api_v1_flaws_list_mitigated_by import OsidbApiV1FlawsListMitigatedBy
 from ...models.osidb_api_v1_flaws_list_resolution import OsidbApiV1FlawsListResolution
-from ...models.osidb_api_v1_flaws_list_response_200 import OsidbApiV1FlawsListResponse200
+from ...models.osidb_api_v1_flaws_list_response_200 import (
+    OsidbApiV1FlawsListResponse200,
+)
 from ...models.osidb_api_v1_flaws_list_source import OsidbApiV1FlawsListSource
 from ...models.osidb_api_v1_flaws_list_state import OsidbApiV1FlawsListState
 from ...models.osidb_api_v1_flaws_list_type import OsidbApiV1FlawsListType
@@ -35,7 +36,6 @@ def _get_kwargs(
     include_fields: Union[Unset, None, List[str]] = UNSET,
     include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
-    mitigated_by: Union[Unset, None, OsidbApiV1FlawsListMitigatedBy] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
     resolution: Union[Unset, None, OsidbApiV1FlawsListResolution] = UNSET,
@@ -109,11 +109,6 @@ def _get_kwargs(
         else:
             json_include_meta_attr = include_meta_attr
 
-    json_mitigated_by: Union[Unset, None, str] = UNSET
-    if not isinstance(mitigated_by, Unset):
-
-        json_mitigated_by = OsidbApiV1FlawsListMitigatedBy(mitigated_by).value if mitigated_by else None
-
     json_reported_dt: Union[Unset, None, str] = UNSET
     if not isinstance(reported_dt, Unset):
         json_reported_dt = reported_dt.isoformat() if reported_dt else None
@@ -121,7 +116,9 @@ def _get_kwargs(
     json_resolution: Union[Unset, None, str] = UNSET
     if not isinstance(resolution, Unset):
 
-        json_resolution = OsidbApiV1FlawsListResolution(resolution).value if resolution else None
+        json_resolution = (
+            OsidbApiV1FlawsListResolution(resolution).value if resolution else None
+        )
 
     json_source: Union[Unset, None, str] = UNSET
     if not isinstance(source, Unset):
@@ -172,7 +169,6 @@ def _get_kwargs(
         "include_fields": json_include_fields,
         "include_meta_attr": json_include_meta_attr,
         "limit": limit,
-        "mitigated_by": json_mitigated_by,
         "offset": offset,
         "reported_dt": json_reported_dt,
         "resolution": json_resolution,
@@ -197,7 +193,9 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1FlawsListResponse200]:
+def _parse_response(
+    *, response: requests.Response
+) -> Optional[OsidbApiV1FlawsListResponse200]:
     if response.status_code == 200:
         _response_200 = response.json()
         response_200: OsidbApiV1FlawsListResponse200
@@ -210,7 +208,9 @@ def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1FlawsL
     return None
 
 
-def _build_response(*, response: requests.Response) -> Response[OsidbApiV1FlawsListResponse200]:
+def _build_response(
+    *, response: requests.Response
+) -> Response[OsidbApiV1FlawsListResponse200]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -240,7 +240,6 @@ def sync_detailed(
     include_fields: Union[Unset, None, List[str]] = UNSET,
     include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
-    mitigated_by: Union[Unset, None, OsidbApiV1FlawsListMitigatedBy] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
     resolution: Union[Unset, None, OsidbApiV1FlawsListResolution] = UNSET,
@@ -276,7 +275,6 @@ def sync_detailed(
         include_fields=include_fields,
         include_meta_attr=include_meta_attr,
         limit=limit,
-        mitigated_by=mitigated_by,
         offset=offset,
         reported_dt=reported_dt,
         resolution=resolution,
@@ -325,7 +323,6 @@ def sync(
     include_fields: Union[Unset, None, List[str]] = UNSET,
     include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
-    mitigated_by: Union[Unset, None, OsidbApiV1FlawsListMitigatedBy] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
     resolution: Union[Unset, None, OsidbApiV1FlawsListResolution] = UNSET,
@@ -363,7 +360,6 @@ def sync(
         include_fields=include_fields,
         include_meta_attr=include_meta_attr,
         limit=limit,
-        mitigated_by=mitigated_by,
         offset=offset,
         reported_dt=reported_dt,
         resolution=resolution,
