@@ -3,7 +3,9 @@ from typing import Any, Dict, List, Optional, Union
 import requests
 
 from ...client import AuthenticatedClient
-from ...models.osidb_api_v1_flaws_retrieve_response_200 import OsidbApiV1FlawsRetrieveResponse200
+from ...models.osidb_api_v1_flaws_retrieve_response_200 import (
+    OsidbApiV1FlawsRetrieveResponse200,
+)
 from ...types import UNSET, Response, Unset
 
 
@@ -75,7 +77,9 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1FlawsRetrieveResponse200]:
+def _parse_response(
+    *, response: requests.Response
+) -> Optional[OsidbApiV1FlawsRetrieveResponse200]:
     if response.status_code == 200:
         _response_200 = response.json()
         response_200: OsidbApiV1FlawsRetrieveResponse200
@@ -88,7 +92,9 @@ def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1FlawsR
     return None
 
 
-def _build_response(*, response: requests.Response) -> Response[OsidbApiV1FlawsRetrieveResponse200]:
+def _build_response(
+    *, response: requests.Response
+) -> Response[OsidbApiV1FlawsRetrieveResponse200]:
     return Response(
         status_code=response.status_code,
         content=response.content,
