@@ -3,7 +3,9 @@ from typing import Any, Dict, Optional
 import requests
 
 from ...client import AuthenticatedClient
-from ...models.osidb_api_v1_status_retrieve_response_200 import OsidbApiV1StatusRetrieveResponse200
+from ...models.osidb_api_v1_status_retrieve_response_200 import (
+    OsidbApiV1StatusRetrieveResponse200,
+)
 from ...types import UNSET, Response, Unset
 
 
@@ -23,7 +25,9 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1StatusRetrieveResponse200]:
+def _parse_response(
+    *, response: requests.Response
+) -> Optional[OsidbApiV1StatusRetrieveResponse200]:
     if response.status_code == 200:
         _response_200 = response.json()
         response_200: OsidbApiV1StatusRetrieveResponse200
@@ -36,7 +40,9 @@ def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1Status
     return None
 
 
-def _build_response(*, response: requests.Response) -> Response[OsidbApiV1StatusRetrieveResponse200]:
+def _build_response(
+    *, response: requests.Response
+) -> Response[OsidbApiV1StatusRetrieveResponse200]:
     return Response(
         status_code=response.status_code,
         content=response.content,
