@@ -4,7 +4,9 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 from dateutil.parser import isoparse
 
-from ..models.exploits_api_v1_cve_map_retrieve_response_200_cves import ExploitsApiV1CveMapRetrieveResponse200Cves
+from ..models.exploits_api_v1_cve_map_retrieve_response_200_cves import (
+    ExploitsApiV1CveMapRetrieveResponse200Cves,
+)
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ExploitsApiV1CveMapRetrieveResponse200")
