@@ -23,7 +23,9 @@ class ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem:
         d = src_dict.copy()
         exploits_api_v1_report_date_retrieve_response_200_not_relevant_item = cls()
 
-        exploits_api_v1_report_date_retrieve_response_200_not_relevant_item.additional_properties = d
+        exploits_api_v1_report_date_retrieve_response_200_not_relevant_item.additional_properties = (
+            d
+        )
         return exploits_api_v1_report_date_retrieve_response_200_not_relevant_item
 
     @property
