@@ -2,7 +2,9 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-T = TypeVar("T", bound="ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem")
+T = TypeVar(
+    "T", bound="ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem"
+)
 
 
 @attr.s(auto_attribs=True)
@@ -21,10 +23,16 @@ class ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item = cls()
+        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item = (
+            cls()
+        )
 
-        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item.additional_properties = d
-        return exploits_api_v1_report_explanations_retrieve_response_200_explanations_item
+        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item.additional_properties = (
+            d
+        )
+        return (
+            exploits_api_v1_report_explanations_retrieve_response_200_explanations_item
+        )
 
     @property
     def additional_keys(self) -> List[str]:
