@@ -2,7 +2,9 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-T = TypeVar("T", bound="ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem")
+T = TypeVar(
+    "T", bound="ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem"
+)
 
 
 @attr.s(auto_attribs=True)
@@ -21,9 +23,13 @@ class ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item = cls()
+        exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item = (
+            cls()
+        )
 
-        exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item.additional_properties = d
+        exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item.additional_properties = (
+            d
+        )
         return exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item
 
     @property
