@@ -14,7 +14,6 @@ from ..models.flaw_resolution_enum import FlawResolutionEnum
 from ..models.flaw_type_enum import FlawTypeEnum
 from ..models.impact_enum import ImpactEnum
 from ..models.meta import Meta
-from ..models.mitigated_by_enum import MitigatedByEnum
 from ..models.source_enum import SourceEnum
 from ..models.state_enum import StateEnum
 from ..types import UNSET, Unset
@@ -31,6 +30,7 @@ class OsidbApiV1FlawsUpdateResponse200:
     trackers: List[str]
     description: str
     embargoed: bool
+    mitigated_by: str
     affects: List[Affect]
     meta: List[Meta]
     comments: List[Comment]
@@ -50,7 +50,6 @@ class OsidbApiV1FlawsUpdateResponse200:
     unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET
     source: Union[BlankEnum, SourceEnum, Unset] = UNSET
     reported_dt: Union[Unset, None, datetime.datetime] = UNSET
-    mitigated_by: Union[BlankEnum, MitigatedByEnum, Unset] = UNSET
     cvss2: Union[Unset, str] = UNSET
     cvss2_score: Union[Unset, None, float] = UNSET
     nvd_cvss2: Union[Unset, str] = UNSET
@@ -73,6 +72,7 @@ class OsidbApiV1FlawsUpdateResponse200:
 
         description = self.description
         embargoed = self.embargoed
+        mitigated_by = self.mitigated_by
         affects: List[Dict[str, Any]] = UNSET
         if not isinstance(self.affects, Unset):
             affects = []
@@ -196,21 +196,6 @@ class OsidbApiV1FlawsUpdateResponse200:
         if not isinstance(self.reported_dt, Unset):
             reported_dt = self.reported_dt.isoformat() if self.reported_dt else None
 
-        mitigated_by: Union[Unset, str]
-        if isinstance(self.mitigated_by, Unset):
-            mitigated_by = UNSET
-        elif isinstance(self.mitigated_by, MitigatedByEnum):
-            mitigated_by = UNSET
-            if not isinstance(self.mitigated_by, Unset):
-
-                mitigated_by = MitigatedByEnum(self.mitigated_by).value
-
-        else:
-            mitigated_by = UNSET
-            if not isinstance(self.mitigated_by, Unset):
-
-                mitigated_by = BlankEnum(self.mitigated_by).value
-
         cvss2 = self.cvss2
         cvss2_score = self.cvss2_score
         nvd_cvss2 = self.nvd_cvss2
@@ -238,6 +223,8 @@ class OsidbApiV1FlawsUpdateResponse200:
             field_dict["description"] = description
         if embargoed is not UNSET:
             field_dict["embargoed"] = embargoed
+        if mitigated_by is not UNSET:
+            field_dict["mitigated_by"] = mitigated_by
         if affects is not UNSET:
             field_dict["affects"] = affects
         if meta is not UNSET:
@@ -276,8 +263,6 @@ class OsidbApiV1FlawsUpdateResponse200:
             field_dict["source"] = source
         if reported_dt is not UNSET:
             field_dict["reported_dt"] = reported_dt
-        if mitigated_by is not UNSET:
-            field_dict["mitigated_by"] = mitigated_by
         if cvss2 is not UNSET:
             field_dict["cvss2"] = cvss2
         if cvss2_score is not UNSET:
@@ -316,6 +301,8 @@ class OsidbApiV1FlawsUpdateResponse200:
 
         embargoed = d.pop("embargoed", UNSET)
 
+        mitigated_by = d.pop("mitigated_by", UNSET)
+
         affects = []
         _affects = d.pop("affects", UNSET)
         if _affects is UNSET:
@@ -379,7 +366,9 @@ class OsidbApiV1FlawsUpdateResponse200:
                 if isinstance(_package_versions_item, Unset):
                     package_versions_item = UNSET
                 else:
-                    package_versions_item = CVEv5PackageVersions.from_dict(_package_versions_item)
+                    package_versions_item = CVEv5PackageVersions.from_dict(
+                        _package_versions_item
+                    )
 
                 package_versions.append(package_versions_item)
 
@@ -420,7 +409,9 @@ class OsidbApiV1FlawsUpdateResponse200:
         else:
             state = StateEnum(_state)
 
-        def _parse_resolution(data: object) -> Union[BlankEnum, FlawResolutionEnum, Unset]:
+        def _parse_resolution(
+            data: object,
+        ) -> Union[BlankEnum, FlawResolutionEnum, Unset]:
             if isinstance(data, Unset):
                 return data
             try:
@@ -531,35 +522,6 @@ class OsidbApiV1FlawsUpdateResponse200:
         else:
             reported_dt = isoparse(_reported_dt)
 
-        def _parse_mitigated_by(data: object) -> Union[BlankEnum, MitigatedByEnum, Unset]:
-            if isinstance(data, Unset):
-                return data
-            try:
-                if not isinstance(data, str):
-                    raise TypeError()
-                _mitigated_by_type_0 = data
-                mitigated_by_type_0: Union[Unset, MitigatedByEnum]
-                if isinstance(_mitigated_by_type_0, Unset):
-                    mitigated_by_type_0 = UNSET
-                else:
-                    mitigated_by_type_0 = MitigatedByEnum(_mitigated_by_type_0)
-
-                return mitigated_by_type_0
-            except:  # noqa: E722
-                pass
-            if not isinstance(data, str):
-                raise TypeError()
-            _mitigated_by_type_1 = data
-            mitigated_by_type_1: Union[Unset, BlankEnum]
-            if isinstance(_mitigated_by_type_1, Unset):
-                mitigated_by_type_1 = UNSET
-            else:
-                mitigated_by_type_1 = BlankEnum(_mitigated_by_type_1)
-
-            return mitigated_by_type_1
-
-        mitigated_by = _parse_mitigated_by(d.pop("mitigated_by", UNSET))
-
         cvss2 = d.pop("cvss2", UNSET)
 
         cvss2_score = d.pop("cvss2_score", UNSET)
@@ -593,6 +555,7 @@ class OsidbApiV1FlawsUpdateResponse200:
             trackers=trackers,
             description=description,
             embargoed=embargoed,
+            mitigated_by=mitigated_by,
             affects=affects,
             meta=meta,
             comments=comments,
@@ -612,7 +575,6 @@ class OsidbApiV1FlawsUpdateResponse200:
             unembargo_dt=unembargo_dt,
             source=source,
             reported_dt=reported_dt,
-            mitigated_by=mitigated_by,
             cvss2=cvss2,
             cvss2_score=cvss2_score,
             nvd_cvss2=nvd_cvss2,
