@@ -1,6 +1,7 @@
 import importlib
 from types import ModuleType
 from typing import Any, Callable, Dict, List
+from warnings import warn
 
 import requests
 from requests_gssapi import HTTPSPNEGOAuth
@@ -29,8 +30,6 @@ osidb_status_retrieve = importlib.import_module(
 class OperationUnsupported(Exception):
     """Session operation is unsupported exception"""
 
-    pass
-
 
 def get_sync_function(api_module: ModuleType) -> Callable:
     """
@@ -112,8 +111,8 @@ class Session:
         self.refresh_token = self.__get_refresh_token()
 
     def status(self):
-        status_fn = self.__get_sync_function(osidb_status_retrieve)
-        return status_fn(client=self.__client_with_new_access_token)
+        status_fn = get_sync_function(osidb_status_retrieve)
+        return status_fn(client=self.__get_client_with_new_access_token())
 
     def __get_refresh_token(self) -> str:
         """Get resfresh token based on the auth type"""
@@ -167,6 +166,67 @@ class Session:
             {"Authorization": f"Bearer {self.__get_access_token()}"}
         )
 
+    # TODO remove following methods with OSIDB 3.0.0 release
+    def retrieve(self, id, **kwargs):
+        warn(
+            (
+                'This is only alias to ".flaws.retrieve" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        return self.flaws.retrieve(id=id, **kwargs)
+
+    def retrieve_list(self, **kwargs):
+        warn(
+            (
+                'This is only alias to ".flaws.retrieve_list" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        return self.flaws.retrieve_list(**kwargs)
+
+    def search(self, searched_text):
+        warn(
+            (
+                'This is only alias to ".flaws.search" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        return self.flaws.search(searched_text=searched_text)
+
+    def create(self, form_data):
+        warn(
+            (
+                'This is only alias to ".flaws.create" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        return self.flaws.create(form_data=form_data)
+
+    def update(self, id, form_data, **kwargs):
+        warn(
+            (
+                'This is only alias to ".flaws.update" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        return self.flaws.update(id=id, form_data=form_data)
+
+    def delete(self):
+        warn(
+            (
+                'This is only alias to ".flaws.delete" and it'
+                "will be deprecated in OSIDB 3.0.0"
+            ),
+            DeprecationWarning,
+        )
+        raise NotImplementedError("Flaw delete not implemented yet.")
+
 
 class SessionOperationsGroup:
     """
